@@ -36,3 +36,11 @@ ascii_fish_tail (void)
         "| <°)))>< |\n"
         "-----------\n");
 }
+
+void
+ascii_fish_dead (void)
+{
+  puts ("-----------\n"
+        "| ======= |\n"
+        "-----------\n");
+}
