@@ -22,21 +22,14 @@ along with goldfish. If not, see <http://www.gnu.org/licenses/>. */
 #ifndef GAMEENGINE_H
 #define GAMEENGINE_H
 
-#include <stdio.h>
-#include <string.h>
-#include <time.h>
-#include <unistd.h>
 #include "aquarium.h"
 #include "fish.h"
-#include "../include/asciifish.h"
 
 void new_game (fish_t *fish, aquarium_t *aquarium,
                game_fish_t *game_fish, game_aquarium_t *game_aquarium);
 int loved_temp (game_aquarium_t *aquarium, game_fish_t *fish);
 int loved_food (game_fish_t *fish);
 int loved_clean_water (game_aquarium_t *aquarium, game_fish_t *fish);
-int random_life_points (void);
-void clear_screen (void);
 void loop_game (game_fish_t *fish);
 
 #endif /* GAMEENGINE_H  */
